#[non_exhaustive]pub struct TransferResourceResponse {
pub source: String,
pub target: String,
pub error: Option<Status>,
/* private fields */
}Expand description
Transfer response for a single resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: StringFull name of the resource to transfer as specified in the request.
target: StringFull name of the new resource successfully transferred from the source hosted by Translation API. Target will be empty if the transfer failed.
error: Option<Status>The error result in case of failure.
Implementations
Sourceimpl TransferResourceResponse
impl TransferResourceResponse
pub fn new() -> Self
Sourcepub fn set_source<T: Into<String>>(self, v: T) -> Self
pub fn set_source<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_target<T: Into<String>>(self, v: T) -> Self
pub fn set_target<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_error<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error<T>(self, v: Option<T>) -> Self