#[non_exhaustive]pub enum OperationState {
Unspecified,
Running,
Succeeded,
Failed,
Cancelling,
Cancelled,
UnknownValue(UnknownValue),
}Expand description
Possible states of long running operations.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Invalid.
Running
Request is being processed.
Succeeded
The operation was successful.
Failed
Failed to process operation.
Cancelling
Request is in the process of being canceled after caller invoked longrunning.Operations.CancelOperation on the request id.
Cancelled
The operation request was successfully canceled.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using OperationState::value or OperationState::name.
Implementations