#[non_exhaustive]pub struct BatchDocumentOutputConfig {
pub destination: Option<Destination>,
/* private fields */
}Expand description
Output configuration for BatchTranslateDocument request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination: Option<Destination>The destination of output. The destination directory provided must exist and be empty.
Implementations
Sourceimpl BatchDocumentOutputConfig
impl BatchDocumentOutputConfig
pub fn new() -> Self
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
ⓘ
use google_cloud_translation_v3::model::GcsDestination;
let x = BatchDocumentOutputConfig::new().set_destination(Some(
google_cloud_translation_v3::model::batch_document_output_config::Destination::GcsDestination(GcsDestination::default().into())));Sourcepub fn gcs_destination(&self) -> Option<&Box<GcsDestination>>
pub fn gcs_destination(&self) -> Option<&Box<GcsDestination>>
The value of destination
if it holds a GcsDestination, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_destination<T: Into<Box<GcsDestination>>>(self, v: T) -> Self
pub fn set_gcs_destination<T: Into<Box<GcsDestination>>>(self, v: T) -> Self
Sets the value of destination
to hold a GcsDestination.
Note that all the setters affecting destination are
mutually exclusive.
Example
ⓘ
use google_cloud_translation_v3::model::GcsDestination;
let x = BatchDocumentOutputConfig::new().set_gcs_destination(GcsDestination::default()/* use setters */);
assert!(x.gcs_destination().is_some());Trait Implementations
Sourceimpl Clone for BatchDocumentOutputConfig
impl Clone for BatchDocumentOutputConfig
Sourcefn clone(&self) -> BatchDocumentOutputConfig
fn clone(&self) -> BatchDocumentOutputConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchDocumentOutputConfig
impl Debug for BatchDocumentOutputConfig
Sourceimpl Default for BatchDocumentOutputConfig
impl Default for BatchDocumentOutputConfig
Sourcefn default() -> BatchDocumentOutputConfig
fn default() -> BatchDocumentOutputConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for BatchDocumentOutputConfig
impl Message for BatchDocumentOutputConfig
impl StructuralPartialEq for BatchDocumentOutputConfig