BatchTranslateMetadata

Struct BatchTranslateMetadata 

#[non_exhaustive]
pub struct BatchTranslateMetadata { pub state: State, pub translated_characters: i64, pub failed_characters: i64, pub total_characters: i64, pub submit_time: Option<Timestamp>, /* private fields */ }
State metadata for the batch translation operation.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
state: State

The state of the operation.

translated_characters: i64

Number of successfully translated characters so far (Unicode codepoints).

failed_characters: i64

Number of characters that have failed to process so far (Unicode codepoints).

total_characters: i64

Total number of characters (Unicode codepoints). This is the total number of codepoints from input files times the number of target languages and appears here shortly after the call is submitted.

submit_time: Option<Timestamp>

Time when the operation was submitted.

Implementations

Source

impl BatchTranslateMetadata

pub fn new() -> Self

pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_translation_v3::model::batch_translate_metadata::State;
let x0 = BatchTranslateMetadata::new().set_state(State::Running);
let x1 = BatchTranslateMetadata::new().set_state(State::Succeeded);
let x2 = BatchTranslateMetadata::new().set_state(State::Failed);
pub fn set_translated_characters<T: Into<i64>>(self, v: T) -> Self

Sets the value of translated_characters.

Example
let x = BatchTranslateMetadata::new().set_translated_characters(42);
pub fn set_failed_characters<T: Into<i64>>(self, v: T) -> Self

Sets the value of failed_characters.

Example
let x = BatchTranslateMetadata::new().set_failed_characters(42);
pub fn set_total_characters<T: Into<i64>>(self, v: T) -> Self

Sets the value of total_characters.

Example
let x = BatchTranslateMetadata::new().set_total_characters(42);
pub fn set_submit_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of submit_time.

Example
use wkt::Timestamp;
let x = BatchTranslateMetadata::new().set_submit_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_submit_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of submit_time.

Example
use wkt::Timestamp;
let x = BatchTranslateMetadata::new().set_or_clear_submit_time(Some(Timestamp::default()/* use setters */));
let x = BatchTranslateMetadata::new().set_or_clear_submit_time(None::<Timestamp>);