#[non_exhaustive]pub struct DatasetOutputConfig {
pub destination: Option<Destination>,
/* private fields */
}Expand description
Output configuration for datasets.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination: Option<Destination>Required. Specify the output.
Implementations
Sourceimpl DatasetOutputConfig
impl DatasetOutputConfig
pub fn new() -> Self
Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
ⓘ
use google_cloud_translation_v3::model::GcsOutputDestination;
let x = DatasetOutputConfig::new().set_destination(Some(
google_cloud_translation_v3::model::dataset_output_config::Destination::GcsDestination(GcsOutputDestination::default().into())));Sourcepub fn gcs_destination(&self) -> Option<&Box<GcsOutputDestination>>
pub fn gcs_destination(&self) -> Option<&Box<GcsOutputDestination>>
The value of destination
if it holds a GcsDestination, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_destination<T: Into<Box<GcsOutputDestination>>>(
self,
v: T,
) -> Self
pub fn set_gcs_destination<T: Into<Box<GcsOutputDestination>>>( self, v: T, ) -> Self
Sets the value of destination
to hold a GcsDestination.
Note that all the setters affecting destination are
mutually exclusive.
Example
ⓘ
use google_cloud_translation_v3::model::GcsOutputDestination;
let x = DatasetOutputConfig::new().set_gcs_destination(GcsOutputDestination::default()/* use setters */);
assert!(x.gcs_destination().is_some());Trait Implementations
Sourceimpl Clone for DatasetOutputConfig
impl Clone for DatasetOutputConfig
Sourcefn clone(&self) -> DatasetOutputConfig
fn clone(&self) -> DatasetOutputConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatasetOutputConfig
impl Debug for DatasetOutputConfig
Sourceimpl Default for DatasetOutputConfig
impl Default for DatasetOutputConfig
Sourcefn default() -> DatasetOutputConfig
fn default() -> DatasetOutputConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for DatasetOutputConfig
impl Message for DatasetOutputConfig
Sourceimpl PartialEq for DatasetOutputConfig
impl PartialEq for DatasetOutputConfig
impl StructuralPartialEq for DatasetOutputConfig