DetectLanguageRequest

Struct DetectLanguageRequest 

#[non_exhaustive]
pub struct DetectLanguageRequest { pub parent: String, pub model: String, pub mime_type: String, pub labels: HashMap<String, String>, pub source: Option<Source>, /* private fields */ }
The request message for language detection.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. Project or location to make a call. Must refer to a caller’s project.

Format: projects/{project-number-or-id}/locations/{location-id} or projects/{project-number-or-id}.

For global calls, use projects/{project-number-or-id}/locations/global or projects/{project-number-or-id}.

Only models within the same region (has same location-id) can be used. Otherwise an INVALID_ARGUMENT (400) error is returned.

model: String

Optional. The language detection model to be used.

Format: projects/{project-number-or-id}/locations/{location-id}/models/language-detection/{model-id}

Only one language detection model is currently supported: projects/{project-number-or-id}/locations/{location-id}/models/language-detection/default.

If not specified, the default model is used.

mime_type: String

Optional. The format of the source text, for example, “text/html”, “text/plain”. If left blank, the MIME type defaults to “text/html”.

labels: HashMap<String, String>

Optional. The labels with user-defined metadata for the request.

Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter.

See https://cloud.google.com/translate/docs/advanced/labels for more information.

source: Option<Source>

Required. The source of the document from which to detect the language.

Implementations

Source

impl DetectLanguageRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = DetectLanguageRequest::new().set_parent("example");
pub fn set_model<T: Into<String>>(self, v: T) -> Self

Sets the value of model.

Example
let x = DetectLanguageRequest::new().set_model("example");
pub fn set_mime_type<T: Into<String>>(self, v: T) -> Self

Sets the value of mime_type.

Example
let x = DetectLanguageRequest::new().set_mime_type("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = DetectLanguageRequest::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self

Sets the value of source.

Note that all the setters affecting source are mutually exclusive.

Example
use google_cloud_translation_v3::model::detect_language_request::Source;
let x = DetectLanguageRequest::new().set_source(Some(Source::Content("example".to_string())));
pub fn content(&self) -> Option<&String>

The value of source if it holds a Content, None if the field is not set or holds a different branch.

pub fn set_content<T: Into<String>>(self, v: T) -> Self

Sets the value of source to hold a Content.

Note that all the setters affecting source are mutually exclusive.

Example
let x = DetectLanguageRequest::new().set_content("example");
assert!(x.content().is_some());