DocumentOutputConfig

Struct DocumentOutputConfig 

#[non_exhaustive]
pub struct DocumentOutputConfig { pub mime_type: String, pub destination: Option<Destination>, /* private fields */ }
A document translation request output config.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
mime_type: String

Optional. Specifies the translated document’s mime_type. If not specified, the translated file’s mime type will be the same as the input file’s mime type. Currently only support the output mime type to be the same as input mime type.

  • application/pdf
  • application/vnd.openxmlformats-officedocument.wordprocessingml.document
  • application/vnd.openxmlformats-officedocument.presentationml.presentation
  • application/vnd.openxmlformats-officedocument.spreadsheetml.sheet
destination: Option<Destination>

A URI destination for the translated document. It is optional to provide a destination. If provided the results from TranslateDocument will be stored in the destination. Whether a destination is provided or not, the translated documents will be returned within TranslateDocumentResponse.document_translation and TranslateDocumentResponse.glossary_document_translation.

Implementations

Source

impl DocumentOutputConfig

pub fn new() -> Self

pub fn set_mime_type<T: Into<String>>(self, v: T) -> Self

Sets the value of mime_type.

Example
let x = DocumentOutputConfig::new().set_mime_type("example");
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self

Sets the value of destination.

Note that all the setters affecting destination are mutually exclusive.

Example
use google_cloud_translation_v3::model::GcsDestination;
let x = DocumentOutputConfig::new().set_destination(Some(
    google_cloud_translation_v3::model::document_output_config::Destination::GcsDestination(GcsDestination::default().into())));
pub fn gcs_destination(&self) -> Option<&Box<GcsDestination>>

The value of destination if it holds a GcsDestination, None if the field is not set or holds a different branch.

pub fn set_gcs_destination<T: Into<Box<GcsDestination>>>(self, v: T) -> Self

Sets the value of destination to hold a GcsDestination.

Note that all the setters affecting destination are mutually exclusive.

Example
use google_cloud_translation_v3::model::GcsDestination;
let x = DocumentOutputConfig::new().set_gcs_destination(GcsDestination::default()/* use setters */);
assert!(x.gcs_destination().is_some());