DocumentTranslation

Struct DocumentTranslation 

#[non_exhaustive]
pub struct DocumentTranslation { pub byte_stream_outputs: Vec<Bytes>, pub mime_type: String, pub detected_language_code: String, /* private fields */ }
A translated document message.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
byte_stream_outputs: Vec<Bytes>

The array of translated documents. It is expected to be size 1 for now. We may produce multiple translated documents in the future for other type of file formats.

mime_type: String

The translated document’s mime type.

detected_language_code: String

The detected language for the input document. If the user did not provide the source language for the input document, this field will have the language code automatically detected. If the source language was passed, auto-detection of the language does not occur and this field is empty.

Implementations

Source

impl DocumentTranslation

pub fn new() -> Self

pub fn set_byte_stream_outputs<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Bytes>,

Sets the value of byte_stream_outputs.

Example
let b1 = bytes::Bytes::from_static(b"abc");
let b2 = bytes::Bytes::from_static(b"xyz");
let x = DocumentTranslation::new().set_byte_stream_outputs([b1, b2]);
pub fn set_mime_type<T: Into<String>>(self, v: T) -> Self

Sets the value of mime_type.

Example
let x = DocumentTranslation::new().set_mime_type("example");
pub fn set_detected_language_code<T: Into<String>>(self, v: T) -> Self

Sets the value of detected_language_code.

Example
let x = DocumentTranslation::new().set_detected_language_code("example");