#[non_exhaustive]pub struct GcsDestination {
pub output_uri_prefix: String,
/* private fields */
}Expand description
The Google Cloud Storage location for the output content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.output_uri_prefix: StringRequired. The bucket used in ‘output_uri_prefix’ must exist and there must be no files under ‘output_uri_prefix’. ‘output_uri_prefix’ must end with “/” and start with “gs://”. One ‘output_uri_prefix’ can only be used by one batch translation job at a time. Otherwise an INVALID_ARGUMENT (400) error is returned.
Implementations
Sourceimpl GcsDestination
impl GcsDestination
pub fn new() -> Self
Sourcepub fn set_output_uri_prefix<T: Into<String>>(self, v: T) -> Self
pub fn set_output_uri_prefix<T: Into<String>>(self, v: T) -> Self
Sets the value of output_uri_prefix.
Example
ⓘ
let x = GcsDestination::new().set_output_uri_prefix("example");Trait Implementations
Sourceimpl Clone for GcsDestination
impl Clone for GcsDestination
Sourcefn clone(&self) -> GcsDestination
fn clone(&self) -> GcsDestination
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GcsDestination
impl Debug for GcsDestination
Sourceimpl Default for GcsDestination
impl Default for GcsDestination
Sourcefn default() -> GcsDestination
fn default() -> GcsDestination
Returns the “default value” for a type. Read more
Sourceimpl Message for GcsDestination
impl Message for GcsDestination
Sourceimpl PartialEq for GcsDestination
impl PartialEq for GcsDestination
impl StructuralPartialEq for GcsDestination