#[non_exhaustive]pub struct ListAdaptiveMtDatasetsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for listing all Adaptive MT datasets that the requestor has access to.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the project from which to list the Adaptive
MT datasets. projects/{project-number-or-id}/locations/{location-id}
page_size: i32Optional. Requested page size. The server may return fewer results than requested. If unspecified, the server picks an appropriate default.
page_token: StringOptional. A token identifying a page of results the server should return.
Typically, this is the value of
ListAdaptiveMtDatasetsResponse.next_page_token returned from the
previous call to ListAdaptiveMtDatasets method. The first page is
returned if page_tokenis empty or missing.
filter: StringOptional. An expression for filtering the results of the request. Filter is not supported yet.
Implementations
Sourceimpl ListAdaptiveMtDatasetsRequest
impl ListAdaptiveMtDatasetsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListAdaptiveMtDatasetsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListAdaptiveMtDatasetsRequest
impl Clone for ListAdaptiveMtDatasetsRequest
Sourcefn clone(&self) -> ListAdaptiveMtDatasetsRequest
fn clone(&self) -> ListAdaptiveMtDatasetsRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for ListAdaptiveMtDatasetsRequest
impl Default for ListAdaptiveMtDatasetsRequest
Sourcefn default() -> ListAdaptiveMtDatasetsRequest
fn default() -> ListAdaptiveMtDatasetsRequest
Sourceimpl PartialEq for ListAdaptiveMtDatasetsRequest
impl PartialEq for ListAdaptiveMtDatasetsRequest
Sourcefn eq(&self, other: &ListAdaptiveMtDatasetsRequest) -> bool
fn eq(&self, other: &ListAdaptiveMtDatasetsRequest) -> bool
self and other values to be equal, and is used by ==.