#[non_exhaustive]pub struct ListAdaptiveMtFilesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
The request to list all AdaptiveMt files under a given dataset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the project from which to list the Adaptive
MT files.
projects/{project}/locations/{location}/adaptiveMtDatasets/{dataset}
page_size: i32Optional.
page_token: StringOptional. A token identifying a page of results the server should return.
Typically, this is the value of
ListAdaptiveMtFilesResponse.next_page_token returned from the
previous call to ListAdaptiveMtFiles method. The first page is
returned if page_tokenis empty or missing.
Implementations
Sourceimpl ListAdaptiveMtFilesRequest
impl ListAdaptiveMtFilesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListAdaptiveMtFilesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListAdaptiveMtFilesRequest
impl Clone for ListAdaptiveMtFilesRequest
Sourcefn clone(&self) -> ListAdaptiveMtFilesRequest
fn clone(&self) -> ListAdaptiveMtFilesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListAdaptiveMtFilesRequest
impl Debug for ListAdaptiveMtFilesRequest
Sourceimpl Default for ListAdaptiveMtFilesRequest
impl Default for ListAdaptiveMtFilesRequest
Sourcefn default() -> ListAdaptiveMtFilesRequest
fn default() -> ListAdaptiveMtFilesRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListAdaptiveMtFilesRequest
impl Message for ListAdaptiveMtFilesRequest
impl StructuralPartialEq for ListAdaptiveMtFilesRequest