RomanizeTextRequest

Struct RomanizeTextRequest 

#[non_exhaustive]
pub struct RomanizeTextRequest { pub parent: String, pub contents: Vec<String>, pub source_language_code: String, /* private fields */ }
The request message for synchronous romanization.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. Project or location to make a call. Must refer to a caller’s project.

Format: projects/{project-number-or-id}/locations/{location-id} or projects/{project-number-or-id}.

For global calls, use projects/{project-number-or-id}/locations/global or projects/{project-number-or-id}.

contents: Vec<String>

Required. The content of the input in string format.

source_language_code: String

Optional. The ISO-639 language code of the input text if known, for example, “hi” or “zh”. Supported language codes are listed in Language Support. If the source language isn’t specified, the API attempts to identify the source language automatically and returns the source language for each content in the response.

Implementations

Source

impl RomanizeTextRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = RomanizeTextRequest::new().set_parent("example");
pub fn set_contents<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of contents.

Example
let x = RomanizeTextRequest::new().set_contents(["a", "b", "c"]);
pub fn set_source_language_code<T: Into<String>>(self, v: T) -> Self

Sets the value of source_language_code.

Example
let x = RomanizeTextRequest::new().set_source_language_code("example");