TranslateTextRequest

Struct TranslateTextRequest 

#[non_exhaustive]
pub struct TranslateTextRequest { pub contents: Vec<String>, pub mime_type: String, pub source_language_code: String, pub target_language_code: String, pub parent: String, pub model: String, pub glossary_config: Option<TranslateTextGlossaryConfig>, pub transliteration_config: Option<TransliterationConfig>, pub labels: HashMap<String, String>, /* private fields */ }
The request message for synchronous translation.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
contents: Vec<String>

Required. The content of the input in string format. We recommend the total content be less than 30,000 codepoints. The max length of this field is 1024. Use BatchTranslateText for larger text.

mime_type: String

Optional. The format of the source text, for example, “text/html”, “text/plain”. If left blank, the MIME type defaults to “text/html”.

source_language_code: String

Optional. The ISO-639 language code of the input text if known, for example, “en-US” or “sr-Latn”. Supported language codes are listed in Language Support. If the source language isn’t specified, the API attempts to identify the source language automatically and returns the source language within the response.

target_language_code: String

Required. The ISO-639 language code to use for translation of the input text, set to one of the language codes listed in Language Support.

parent: String

Required. Project or location to make a call. Must refer to a caller’s project.

Format: projects/{project-number-or-id} or projects/{project-number-or-id}/locations/{location-id}.

For global calls, use projects/{project-number-or-id}/locations/global or projects/{project-number-or-id}.

Non-global location is required for requests using AutoML models or custom glossaries.

Models and glossaries must be within the same region (have same location-id), otherwise an INVALID_ARGUMENT (400) error is returned.

model: String

Optional. The model type requested for this translation.

The format depends on model type:

  • AutoML Translation models: projects/{project-number-or-id}/locations/{location-id}/models/{model-id}

  • General (built-in) models: projects/{project-number-or-id}/locations/{location-id}/models/general/nmt,

  • Translation LLM models: projects/{project-number-or-id}/locations/{location-id}/models/general/translation-llm,

For global (non-regionalized) requests, use location-id global. For example, projects/{project-number-or-id}/locations/global/models/general/nmt.

If not provided, the default Google model (NMT) will be used

glossary_config: Option<TranslateTextGlossaryConfig>

Optional. Glossary to be applied. The glossary must be within the same region (have the same location-id) as the model, otherwise an INVALID_ARGUMENT (400) error is returned.

transliteration_config: Option<TransliterationConfig>

Optional. Transliteration to be applied.

labels: HashMap<String, String>

Optional. The labels with user-defined metadata for the request.

Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter.

See https://cloud.google.com/translate/docs/advanced/labels for more information.

Implementations

Source

impl TranslateTextRequest

pub fn new() -> Self

pub fn set_contents<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of contents.

Example
let x = TranslateTextRequest::new().set_contents(["a", "b", "c"]);
pub fn set_mime_type<T: Into<String>>(self, v: T) -> Self

Sets the value of mime_type.

Example
let x = TranslateTextRequest::new().set_mime_type("example");
pub fn set_source_language_code<T: Into<String>>(self, v: T) -> Self

Sets the value of source_language_code.

Example
let x = TranslateTextRequest::new().set_source_language_code("example");
pub fn set_target_language_code<T: Into<String>>(self, v: T) -> Self

Sets the value of target_language_code.

Example
let x = TranslateTextRequest::new().set_target_language_code("example");
pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = TranslateTextRequest::new().set_parent("example");
pub fn set_model<T: Into<String>>(self, v: T) -> Self

Sets the value of model.

Example
let x = TranslateTextRequest::new().set_model("example");
pub fn set_glossary_config<T>(self, v: T) -> Self

Sets the value of glossary_config.

Example
use google_cloud_translation_v3::model::TranslateTextGlossaryConfig;
let x = TranslateTextRequest::new().set_glossary_config(TranslateTextGlossaryConfig::default()/* use setters */);
pub fn set_or_clear_glossary_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of glossary_config.

Example
use google_cloud_translation_v3::model::TranslateTextGlossaryConfig;
let x = TranslateTextRequest::new().set_or_clear_glossary_config(Some(TranslateTextGlossaryConfig::default()/* use setters */));
let x = TranslateTextRequest::new().set_or_clear_glossary_config(None::<TranslateTextGlossaryConfig>);
pub fn set_transliteration_config<T>(self, v: T) -> Self

Sets the value of transliteration_config.

Example
use google_cloud_translation_v3::model::TransliterationConfig;
let x = TranslateTextRequest::new().set_transliteration_config(TransliterationConfig::default()/* use setters */);
pub fn set_or_clear_transliteration_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of transliteration_config.

Example
use google_cloud_translation_v3::model::TransliterationConfig;
let x = TranslateTextRequest::new().set_or_clear_transliteration_config(Some(TransliterationConfig::default()/* use setters */));
let x = TranslateTextRequest::new().set_or_clear_transliteration_config(None::<TransliterationConfig>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = TranslateTextRequest::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);