pub struct TranslationService { /* private fields */ }Expand description
Implements a client for the Cloud Translation API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = TranslationService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_glossaries()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Provides natural language translation operations.
Configuration
To configure TranslationService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://translate.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
TranslationService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap TranslationService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl TranslationService
impl TranslationService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for TranslationService.
let client = TranslationService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: TranslationService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: TranslationService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn translate_text(&self) -> TranslateText
pub fn translate_text(&self) -> TranslateText
Translates input text and returns translated text.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.translate_text()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn romanize_text(&self) -> RomanizeText
pub fn romanize_text(&self) -> RomanizeText
Romanize input text written in non-Latin scripts to Latin text.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.romanize_text()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn detect_language(&self) -> DetectLanguage
pub fn detect_language(&self) -> DetectLanguage
Detects the language of text within a request.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.detect_language()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_supported_languages(&self) -> GetSupportedLanguages
pub fn get_supported_languages(&self) -> GetSupportedLanguages
Returns a list of supported languages for translation.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.get_supported_languages()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn translate_document(&self) -> TranslateDocument
pub fn translate_document(&self) -> TranslateDocument
Translates documents in synchronous mode.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.translate_document()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_translate_text(&self) -> BatchTranslateText
pub fn batch_translate_text(&self) -> BatchTranslateText
Translates a large volume of text in asynchronous batch mode. This function provides real-time output as the inputs are being processed. If caller cancels a request, the partial results (for an input file, it’s all or nothing) may still be available on the specified output location.
This call returns immediately and you can use google.longrunning.Operation.name to poll the status of the call.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.batch_translate_text()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_translate_document(&self) -> BatchTranslateDocument
pub fn batch_translate_document(&self) -> BatchTranslateDocument
Translates a large volume of document in asynchronous batch mode. This function provides real-time output as the inputs are being processed. If caller cancels a request, the partial results (for an input file, it’s all or nothing) may still be available on the specified output location.
This call returns immediately and you can use google.longrunning.Operation.name to poll the status of the call.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.batch_translate_document()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_glossary(&self) -> CreateGlossary
pub fn create_glossary(&self) -> CreateGlossary
Creates a glossary and returns the long-running operation. Returns NOT_FOUND, if the project doesn’t exist.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::model::Glossary;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let response = client.create_glossary()
.set_parent(parent)
.set_glossary(
Glossary::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_glossary(&self) -> UpdateGlossary
pub fn update_glossary(&self) -> UpdateGlossary
Updates a glossary. A LRO is used since the update can be async if the glossary’s entry file is updated.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_translation_v3::model::Glossary;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.update_glossary()
.set_glossary(
Glossary::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_glossaries(&self) -> ListGlossaries
pub fn list_glossaries(&self) -> ListGlossaries
Lists glossaries in a project. Returns NOT_FOUND, if the project doesn’t exist.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let mut list = client.list_glossaries()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_glossary(&self) -> GetGlossary
pub fn get_glossary(&self) -> GetGlossary
Gets a glossary. Returns NOT_FOUND, if the glossary doesn’t exist.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.get_glossary()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_glossary(&self) -> DeleteGlossary
pub fn delete_glossary(&self) -> DeleteGlossary
Deletes a glossary, or cancels glossary construction if the glossary isn’t created yet. Returns NOT_FOUND, if the glossary doesn’t exist.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.delete_glossary()
.set_name(name)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_glossary_entry(&self) -> GetGlossaryEntry
pub fn get_glossary_entry(&self) -> GetGlossaryEntry
Gets a single glossary entry by the given id.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.get_glossary_entry()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_glossary_entries(&self) -> ListGlossaryEntries
pub fn list_glossary_entries(&self) -> ListGlossaryEntries
List the entries for the glossary.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let mut list = client.list_glossary_entries()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn create_glossary_entry(&self) -> CreateGlossaryEntry
pub fn create_glossary_entry(&self) -> CreateGlossaryEntry
Creates a glossary entry.
Example
use google_cloud_translation_v3::model::GlossaryEntry;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let response = client.create_glossary_entry()
.set_parent(parent)
.set_glossary_entry(
GlossaryEntry::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_glossary_entry(&self) -> UpdateGlossaryEntry
pub fn update_glossary_entry(&self) -> UpdateGlossaryEntry
Updates a glossary entry.
Example
use google_cloud_translation_v3::model::GlossaryEntry;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.update_glossary_entry()
.set_glossary_entry(
GlossaryEntry::new().set_name(name)/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_glossary_entry(&self) -> DeleteGlossaryEntry
pub fn delete_glossary_entry(&self) -> DeleteGlossaryEntry
Deletes a single entry from the glossary
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
client.delete_glossary_entry()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn create_dataset(&self) -> CreateDataset
pub fn create_dataset(&self) -> CreateDataset
Creates a Dataset.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::model::Dataset;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let response = client.create_dataset()
.set_parent(parent)
.set_dataset(
Dataset::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_dataset(&self) -> GetDataset
pub fn get_dataset(&self) -> GetDataset
Gets a Dataset.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.get_dataset()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_datasets(&self) -> ListDatasets
pub fn list_datasets(&self) -> ListDatasets
Lists datasets.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let mut list = client.list_datasets()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_dataset(&self) -> DeleteDataset
pub fn delete_dataset(&self) -> DeleteDataset
Deletes a dataset and all of its contents.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
client.delete_dataset()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn create_adaptive_mt_dataset(&self) -> CreateAdaptiveMtDataset
pub fn create_adaptive_mt_dataset(&self) -> CreateAdaptiveMtDataset
Creates an Adaptive MT dataset.
Example
use google_cloud_translation_v3::model::AdaptiveMtDataset;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let response = client.create_adaptive_mt_dataset()
.set_parent(parent)
.set_adaptive_mt_dataset(
AdaptiveMtDataset::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_adaptive_mt_dataset(&self) -> DeleteAdaptiveMtDataset
pub fn delete_adaptive_mt_dataset(&self) -> DeleteAdaptiveMtDataset
Deletes an Adaptive MT dataset, including all its entries and associated metadata.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
client.delete_adaptive_mt_dataset()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn get_adaptive_mt_dataset(&self) -> GetAdaptiveMtDataset
pub fn get_adaptive_mt_dataset(&self) -> GetAdaptiveMtDataset
Gets the Adaptive MT dataset.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.get_adaptive_mt_dataset()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_adaptive_mt_datasets(&self) -> ListAdaptiveMtDatasets
pub fn list_adaptive_mt_datasets(&self) -> ListAdaptiveMtDatasets
Lists all Adaptive MT datasets for which the caller has read permission.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let mut list = client.list_adaptive_mt_datasets()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn adaptive_mt_translate(&self) -> AdaptiveMtTranslate
pub fn adaptive_mt_translate(&self) -> AdaptiveMtTranslate
Translate text using Adaptive MT.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.adaptive_mt_translate()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_adaptive_mt_file(&self) -> GetAdaptiveMtFile
pub fn get_adaptive_mt_file(&self) -> GetAdaptiveMtFile
Gets and AdaptiveMtFile
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.get_adaptive_mt_file()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_adaptive_mt_file(&self) -> DeleteAdaptiveMtFile
pub fn delete_adaptive_mt_file(&self) -> DeleteAdaptiveMtFile
Deletes an AdaptiveMtFile along with its sentences.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
client.delete_adaptive_mt_file()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn import_adaptive_mt_file(&self) -> ImportAdaptiveMtFile
pub fn import_adaptive_mt_file(&self) -> ImportAdaptiveMtFile
Imports an AdaptiveMtFile and adds all of its sentences into the AdaptiveMtDataset.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.import_adaptive_mt_file()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_adaptive_mt_files(&self) -> ListAdaptiveMtFiles
pub fn list_adaptive_mt_files(&self) -> ListAdaptiveMtFiles
Lists all AdaptiveMtFiles associated to an AdaptiveMtDataset.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let mut list = client.list_adaptive_mt_files()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_adaptive_mt_sentences(&self) -> ListAdaptiveMtSentences
pub fn list_adaptive_mt_sentences(&self) -> ListAdaptiveMtSentences
Lists all AdaptiveMtSentences under a given file/dataset.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let mut list = client.list_adaptive_mt_sentences()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn import_data(&self) -> ImportData
pub fn import_data(&self) -> ImportData
Import sentence pairs into translation Dataset.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
client.import_data()
/* set fields */
.poller().until_done().await?;
Ok(())
}Sourcepub fn export_data(&self) -> ExportData
pub fn export_data(&self) -> ExportData
Exports dataset’s data to the provided output location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
client.export_data()
/* set fields */
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_examples(&self) -> ListExamples
pub fn list_examples(&self) -> ListExamples
Lists sentence pairs in the dataset.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let mut list = client.list_examples()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn create_model(&self) -> CreateModel
pub fn create_model(&self) -> CreateModel
Creates a Model.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::model::Model;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let response = client.create_model()
.set_parent(parent)
.set_model(
Model::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_models(&self) -> ListModels
pub fn list_models(&self) -> ListModels
Lists models.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, parent: &str
) -> Result<()> {
let mut list = client.list_models()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_model(&self) -> GetModel
pub fn get_model(&self) -> GetModel
Gets a model.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
let response = client.get_model()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_model(&self) -> DeleteModel
pub fn delete_model(&self) -> DeleteModel
Deletes a model.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService, name: &str
) -> Result<()> {
client.delete_model()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn wait_operation(&self) -> WaitOperation
pub fn wait_operation(&self) -> WaitOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_translation_v3::Result;
async fn sample(
client: &TranslationService
) -> Result<()> {
let response = client.wait_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for TranslationService
impl Clone for TranslationService
Sourcefn clone(&self) -> TranslationService
fn clone(&self) -> TranslationService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more