#[non_exhaustive]pub struct BatchTranslateDocumentRequest {
pub parent: String,
pub source_language_code: String,
pub target_language_codes: Vec<String>,
pub input_configs: Vec<BatchDocumentInputConfig>,
pub output_config: Option<BatchDocumentOutputConfig>,
pub models: HashMap<String, String>,
pub glossaries: HashMap<String, TranslateTextGlossaryConfig>,
pub format_conversions: HashMap<String, String>,
pub customized_attribution: String,
pub enable_shadow_removal_native_pdf: bool,
pub enable_rotation_correction: bool,
/* private fields */
}Expand description
The BatchTranslateDocument request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Location to make a regional call.
Format: projects/{project-number-or-id}/locations/{location-id}.
The global location is not supported for batch translation.
Only AutoML Translation models or glossaries within the same region (have the same location-id) can be used, otherwise an INVALID_ARGUMENT (400) error is returned.
source_language_code: StringRequired. The ISO-639 language code of the input document if known, for example, “en-US” or “sr-Latn”. Supported language codes are listed in Language Support.
target_language_codes: Vec<String>Required. The ISO-639 language code to use for translation of the input document. Specify up to 10 language codes here. Supported language codes are listed in Language Support.
input_configs: Vec<BatchDocumentInputConfig>Required. Input configurations. The total number of files matched should be <= 100. The total content size to translate should be <= 100M Unicode codepoints. The files must use UTF-8 encoding.
output_config: Option<BatchDocumentOutputConfig>Required. Output configuration. If 2 input configs match to the same file (that is, same input path), we don’t generate output for duplicate inputs.
models: HashMap<String, String>Optional. The models to use for translation. Map’s key is target language code. Map’s value is the model name. Value can be a built-in general model, or an AutoML Translation model.
The value format depends on model type:
-
AutoML Translation models:
projects/{project-number-or-id}/locations/{location-id}/models/{model-id} -
General (built-in) models:
projects/{project-number-or-id}/locations/{location-id}/models/general/nmt,
If the map is empty or a specific model is not requested for a language pair, then default google model (nmt) is used.
glossaries: HashMap<String, TranslateTextGlossaryConfig>Optional. Glossaries to be applied. It’s keyed by target language code.
format_conversions: HashMap<String, String>Optional. The file format conversion map that is applied to all input files. The map key is the original mime_type. The map value is the target mime_type of translated documents.
Supported file format conversion includes:
application/pdftoapplication/vnd.openxmlformats-officedocument.wordprocessingml.document
If nothing specified, output files will be in the same format as the original file.
customized_attribution: StringOptional. This flag is to support user customized attribution.
If not provided, the default is Machine Translated by Google.
Customized attribution should follow rules in
https://cloud.google.com/translate/attribution#attribution_and_logos
enable_shadow_removal_native_pdf: boolOptional. If true, use the text removal server to remove the shadow text on background image for native pdf translation. Shadow removal feature can only be enabled when is_translate_native_pdf_only: false && pdf_native_only: false
enable_rotation_correction: boolOptional. If true, enable auto rotation correction in DVS.
Implementations
Sourceimpl BatchTranslateDocumentRequest
impl BatchTranslateDocumentRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_source_language_code<T: Into<String>>(self, v: T) -> Self
pub fn set_source_language_code<T: Into<String>>(self, v: T) -> Self
Sets the value of source_language_code.
Example
let x = BatchTranslateDocumentRequest::new().set_source_language_code("example");Sourcepub fn set_target_language_codes<T, V>(self, v: T) -> Self
pub fn set_target_language_codes<T, V>(self, v: T) -> Self
Sets the value of target_language_codes.
Example
let x = BatchTranslateDocumentRequest::new().set_target_language_codes(["a", "b", "c"]);Sourcepub fn set_input_configs<T, V>(self, v: T) -> Self
pub fn set_input_configs<T, V>(self, v: T) -> Self
Sets the value of input_configs.
Example
use google_cloud_translation_v3::model::BatchDocumentInputConfig;
let x = BatchTranslateDocumentRequest::new()
.set_input_configs([
BatchDocumentInputConfig::default()/* use setters */,
BatchDocumentInputConfig::default()/* use (different) setters */,
]);Sourcepub fn set_output_config<T>(self, v: T) -> Selfwhere
T: Into<BatchDocumentOutputConfig>,
pub fn set_output_config<T>(self, v: T) -> Selfwhere
T: Into<BatchDocumentOutputConfig>,
Sets the value of output_config.
Example
use google_cloud_translation_v3::model::BatchDocumentOutputConfig;
let x = BatchTranslateDocumentRequest::new().set_output_config(BatchDocumentOutputConfig::default()/* use setters */);Sourcepub fn set_or_clear_output_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<BatchDocumentOutputConfig>,
pub fn set_or_clear_output_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<BatchDocumentOutputConfig>,
Sets or clears the value of output_config.
Example
use google_cloud_translation_v3::model::BatchDocumentOutputConfig;
let x = BatchTranslateDocumentRequest::new().set_or_clear_output_config(Some(BatchDocumentOutputConfig::default()/* use setters */));
let x = BatchTranslateDocumentRequest::new().set_or_clear_output_config(None::<BatchDocumentOutputConfig>);Sourcepub fn set_models<T, K, V>(self, v: T) -> Self
pub fn set_models<T, K, V>(self, v: T) -> Self
Sourcepub fn set_glossaries<T, K, V>(self, v: T) -> Self
pub fn set_glossaries<T, K, V>(self, v: T) -> Self
Sets the value of glossaries.
Example
use google_cloud_translation_v3::model::TranslateTextGlossaryConfig;
let x = BatchTranslateDocumentRequest::new().set_glossaries([
("key0", TranslateTextGlossaryConfig::default()/* use setters */),
("key1", TranslateTextGlossaryConfig::default()/* use (different) setters */),
]);Sourcepub fn set_format_conversions<T, K, V>(self, v: T) -> Self
pub fn set_format_conversions<T, K, V>(self, v: T) -> Self
Sets the value of format_conversions.
Example
let x = BatchTranslateDocumentRequest::new().set_format_conversions([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_customized_attribution<T: Into<String>>(self, v: T) -> Self
pub fn set_customized_attribution<T: Into<String>>(self, v: T) -> Self
Sets the value of customized_attribution.
Example
let x = BatchTranslateDocumentRequest::new().set_customized_attribution("example");Sourcepub fn set_enable_shadow_removal_native_pdf<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_shadow_removal_native_pdf<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_shadow_removal_native_pdf.
Example
let x = BatchTranslateDocumentRequest::new().set_enable_shadow_removal_native_pdf(true);Sourcepub fn set_enable_rotation_correction<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_rotation_correction<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_rotation_correction.
Example
let x = BatchTranslateDocumentRequest::new().set_enable_rotation_correction(true);Trait Implementations
Sourceimpl Clone for BatchTranslateDocumentRequest
impl Clone for BatchTranslateDocumentRequest
Sourcefn clone(&self) -> BatchTranslateDocumentRequest
fn clone(&self) -> BatchTranslateDocumentRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for BatchTranslateDocumentRequest
impl Default for BatchTranslateDocumentRequest
Sourcefn default() -> BatchTranslateDocumentRequest
fn default() -> BatchTranslateDocumentRequest
Sourceimpl PartialEq for BatchTranslateDocumentRequest
impl PartialEq for BatchTranslateDocumentRequest
Sourcefn eq(&self, other: &BatchTranslateDocumentRequest) -> bool
fn eq(&self, other: &BatchTranslateDocumentRequest) -> bool
self and other values to be equal, and is used by ==.